summaryrefslogtreecommitdiff
path: root/internal/discovery
diff options
context:
space:
mode:
authorPaul Bütow <pbuetow@mimecast.com>2020-01-26 11:26:53 +0000
committerPaul Bütow <pbuetow@mimecast.com>2020-02-07 13:31:15 +0000
commit0945da8dfefcbb723eecea0e5f4eafff63398253 (patch)
treef06dab4d2bf21d25d176b23d5baeca588d27f5d7 /internal/discovery
parent2a8e5de265a0e0a31a5834909d6879f5c9941467 (diff)
Introduce drun command, refactor code to use context package
Diffstat (limited to 'internal/discovery')
-rw-r--r--internal/discovery/comma.go2
-rw-r--r--internal/discovery/discovery.go21
-rw-r--r--internal/discovery/file.go2
3 files changed, 17 insertions, 8 deletions
diff --git a/internal/discovery/comma.go b/internal/discovery/comma.go
index ad18be0..94276c7 100644
--- a/internal/discovery/comma.go
+++ b/internal/discovery/comma.go
@@ -1,7 +1,7 @@
package discovery
import (
- "github.com/mimecast/dtail/internal/logger"
+ "github.com/mimecast/dtail/internal/io/logger"
"strings"
)
diff --git a/internal/discovery/file.go b/internal/discovery/file.go
index 2edc867..c04173e 100644
--- a/internal/discovery/file.go
+++ b/internal/discovery/file.go
@@ -2,7 +2,7 @@ package discovery
import (
"bufio"
- "github.com/mimecast/dtail/internal/logger"
+ "github.com/mimecast/dtail/internal/io/logger"
"os"
)
diff --git a/internal/discovery/discovery.go b/internal/discovery/discovery.go
index d76c1b2..1090ea9 100644
--- a/internal/discovery/discovery.go
+++ b/internal/discovery/discovery.go
@@ -1,7 +1,6 @@
package discovery
import (
- "github.com/mimecast/dtail/internal/logger"
"fmt"
"math/rand"
"os"
@@ -9,6 +8,16 @@ import (
"regexp"
"strings"
"time"
+
+ "github.com/mimecast/dtail/internal/io/logger"
+)
+
+// ServerOrder to specify how to sort the server list.
+type ServerOrder int
+
+const (
+ // Shuffle the server list?
+ Shuffle ServerOrder = iota
)
// Discovery method for discovering a list of available DTail servers.
@@ -21,12 +30,12 @@ type Discovery struct {
server string
// To filter server list.
regex *regexp.Regexp
- // To shuffle resulting server list.
- shuffle bool
+ // How to order the server list.
+ order ServerOrder
}
// New returns a new discovery method.
-func New(method, server string, shuffle bool) *Discovery {
+func New(method, server string, order ServerOrder) *Discovery {
module := method
options := ""
@@ -43,7 +52,7 @@ func New(method, server string, shuffle bool) *Discovery {
module: strings.ToUpper(module),
options: options,
server: server,
- shuffle: shuffle,
+ order: order,
}
if strings.HasPrefix(server, "/") && strings.HasSuffix(server, "/") {
@@ -84,7 +93,7 @@ func (d *Discovery) ServerList() []string {
servers = d.dedupList(servers)
- if d.shuffle {
+ if d.order == Shuffle {
servers = d.shuffleList(servers)
}